@@ -3,17 +3,20 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 #
-# SPDX-License_indentifier: GPL-2.0-or-later
+# SPDX-License-Identifier: GPL-2.0-or-later
 import logging
+from mercurial import pycompat
 
-CONFIG_SECTION = 'logging'
+CONFIG_SECTION = b'logging'
+
+# default formats have same type as if it were obtained from `ui.config()`
 DEFAULT_GENERAL_FORMAT = (
     "[%(asctime)s] [%(process)d] [%(levelname)s] [%(name)s] %(message)s"
 )
 DEFAULT_HG_FORMAT = (
-    "[%(asctime)s] [%(process)d] [%(levelname)s] "
-    "repo:%(repo)s "
-    "[%(name)s] %(message)s"
+    b"[%(asctime)s] [%(process)d] [%(levelname)s] "
+    b"repo:%(repo)s "
+    b"[%(name)s] %(message)s"
 )
 
 
@@ -22,4 +25,4 @@ def loglevel(levelname):
 
     This is meant to be usable with `ui.configwith`.
     """
-    return getattr(logging, levelname.strip().upper())
+    return getattr(logging, pycompat.sysstr(levelname).strip().upper())
